HTTP signaling service +  webrtc + websocket transports I/O bridge:
<img width="1151" alt="image" src="https://github.com/user-attachments/assets/59e9eace-b27f-4f4c-b314-ee5988988335" />
Websocket signaling service +  webrtc + websocket transports I/O bridge:
<img width="1167" alt="image" src="https://github.com/user-attachments/assets/3963ff54-77ff-4c2f-a41f-7f9e9029d041" />

---

Websocket signaling service +  websocket + webrtc-queue transports I/O bridge:
<img width="1183" height="405" alt="image" src="https://github.com/user-attachments/assets/557056cf-07db-494b-a289-f363fc82ac0b" />

---

Local/Global Scheduler + webrtc-queue bots :
<img width="1172" height="477" alt="image" src="https://github.com/user-attachments/assets/f1c074e6-220c-478f-9435-05b3a7d4d083" />

